@@ -411,8 +411,14 @@ void Bayonne::compileDir(const char *prefix, ScriptCompiler *img)
 		ext = strrchr(file, '.');
 		if(ext && strstr(Script::exec_extensions, ext))
 			goto compile;
-		if(!ext || stricmp(ext, ".scr"))
-			continue;
+
+		if(ext && !stricmp(ext, ".scr"))
+			goto compile;
+
+		if(ext && !stricmp(ext, ".mac"))
+			goto compile;
+
+		continue;
 compile:
 		++compile_count;
 		setString(pp, len, file);
@@ -557,6 +563,15 @@ compile:
 		img->compile(prefix);
 	}
 
+        prefix = server->getLast("addons");
+        if(prefix)
+        {
+                if(isDir(prefix))
+                        compileDir(prefix, img);
+                else
+        		slog.error() << prefix << ": directory missing" << endl;
+        } 
+
 	prefix = server->getLast("scripts");
 	if(prefix)
 	{
@@ -565,6 +580,7 @@ compile:
 		else
 			slog.error() << prefix << ": directory missing" << endl;
 	}
+
 	prefix = server->getLast("apps");
 	if(prefix)
 	{
