@@ -158,6 +158,14 @@ public:
 	 */
 	result_t sendResult(const char *text);
 
+	/**
+	 * Transfer a call.
+	 *
+	 * @return result code from server.
+	 * @param destination to transfer.
+	 */
+	result_t xferCall(const char *dest);
+
 	/**
 	 * Replay an audio file.
 	 *
@@ -290,6 +298,7 @@ protected:
 	void sysHangup(const char *tsid);
 	void sysExit(const char *tsid, char *token);
 	void sysReturn(const char *tsid, const char *text);
+	void sysXfer(const char *tsid, const char *dest);
 };
 
 /**
