@@ -658,15 +658,15 @@ void BayonneTSession::sysReturn(const char *tsid, const char *text)
 			case symPROPERTY:
 			case symNUMBER:
 			case symCOUNTER:
-				commit(sym, text);
+				Script::commit(sym, text);
 				break;
 			case symNORMAL:
 			case symINITIAL:
 				if(sym->data[0])
-					append(sym, pack);
+					Script::append(sym, pack);
 				sym->type = symNORMAL;
 			default:
-				append(sym, text);			
+				Script::append(sym, text);			
 			}	
 			state.result = RESULT_SUCCESS;
 		}
