@@ -45,7 +45,10 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	if(env)
 		loadFile(env, "capi");
 #else
-	load("~bayonne/capi");
+	if(Bayonne::provision_system)
+		load("/bayonne/provision/capi");
+	else if(Bayonne::provision_user)
+		load("~bayonne/capi");
 #endif
 }
 
