@@ -201,6 +201,7 @@ void Driver::startDriver(void)
 	const char *cp;
 	unsigned max_count = ts_count;
 	cp = server->getLast("slots.sip");
+	int rtn;
 
 	exiting = false;
 	timeslot = ts_used;
@@ -217,6 +218,37 @@ void Driver::startDriver(void)
 		return;
 
 
+#ifdef	HAVE_EXOSIP2
+	eXosip_init();
+
+	for(;;)
+	{
+		cp = getLast("transport");
+		if(!cp)
+			cp = "udp";
+
+		if(!stricmp(cp, "tcp"))
+			rtn = eXosip_listen_addr(IPPROTO_TCP, NULL, sip_port, AF_INET, 0);
+		else if(!stricmp(cp, "tls"))
+			rtn = eXosip_listen_addr(IPPROTO_TCP, NULL, sip_port, AF_INET, 1);
+		else
+			rtn = eXosip_listen_addr(IPPROTO_UDP, NULL, sip_port, AF_INET, 0);
+
+		if(!rtn)
+			break;
+
+		slog.error("sip: failed to bind %d", sip_port);
+		if(tries++ > 3)
+		{
+			eXosip_quit();
+			return;
+		}
+		sip_port += 10;
+		if(!getLast("rtp"))
+			rtp_port += 10;
+	}
+
+#else
 	while(eXosip_init(NULL, NULL, sip_port))
 	{
 		slog.error("sip: failed to bind %d", sip_port);
@@ -226,6 +258,7 @@ void Driver::startDriver(void)
 		if(!getLast("rtp"))
 			rtp_port += 10;
 	}
+#endif
 
 	cp = getLast("interface");
 	if(!cp)
@@ -245,7 +278,9 @@ void Driver::startDriver(void)
         osip_trace_enable_level(TRACE_LEVEL6);
         osip_trace_enable_level(TRACE_LEVEL7);
 
+#ifndef	HAVE_EXOSIP2
 	eXosip_sdp_negotiation_remove_audio_payloads();
+#endif
 
 	switch(info.encoding)
 	{
@@ -286,9 +321,12 @@ void Driver::startDriver(void)
 		return;
 	}
 
+#ifndef	HAVE_EXOSIP2
 	eXosip_sdp_negotiation_add_codec(
 		strdup(getLast("payload")), NULL, strdup("RTP/AVP"), 
 		NULL, NULL, NULL, NULL, NULL, strdup(cbuf));
+#endif
+
 	slog.debug("sip: adding sdp encoding %s", cbuf);
 	info.annotation = strdup(cbuf);
 
@@ -297,13 +335,16 @@ void Driver::startDriver(void)
 		snprintf(cbuf, sizeof(cbuf), "%d telephony-event/%d", 
 			dtmf_payload, info.rate);
 		slog.debug("sip: adding sdp encoding %s", cbuf);
+#ifndef	HAVE_EXOSIP2
 		eXosip_sdp_negotiation_add_codec(
 			strdup(getLast("dtmf")), NULL, strdup("RTP/AVP"), 
 			NULL, NULL, NULL, NULL, NULL, strdup(cbuf));
+#endif
 	}
 
 	eXosip_set_user_agent("GNU Bayonne");
 
+#ifndef	HAVE_EXOSIP2
 	cp = getLast("local");
 	if(cp)
 	{
@@ -317,6 +358,7 @@ void Driver::startDriver(void)
 		InetAddress fa = cp;
 		eXosip_set_firewallip(fa.getHostname());
 	}
+#endif
 
 	slog.debug("sip: bound to port %d", sip_port);
 	msgport->start();
@@ -774,7 +816,11 @@ void Driver::run(void)
                         event.id = CALL_ANSWERED;
                         session->postEvent(&event);
                         break;  
+#ifdef	HAVE_EXOSIP2
+		case EXOSIP_CALL_INVITE:
+#else
 		case EXOSIP_CALL_NEW:
+#endif
 			dialed = sevent->req_uri;
 
 			snprintf(cbuf, sizeof(cbuf), "%s", sevent->remote_uri);
@@ -1032,7 +1078,10 @@ failcode:
 				session->getRemotePort());
 			session->setConst("session.rtp_remote", buf);
 			event.id = CALL_CONNECTED;
-			session->postEvent(&event);
+			session->enterMutex();
+			if(session->postEvent(&event))
+				session->did = sevent->did;
+			session->leaveMutex();
 			break;
 		case EXOSIP_CALL_ACK:
 			session = getCall(sevent->cid);
@@ -1129,6 +1178,7 @@ exitcall:
 
 				memset(&event, 0, sizeof(event));
 				event.id = DTMF_KEYUP;
+				session->dtmf_inband = false;
 				switch(*digit)
 				{
 				case '0':
