@@ -33,6 +33,9 @@ TimerPort()
 	cid = 0;
 	did = 0;
 	rtp = NULL;
+	dtmf_payload = Driver::sip.dtmf_payload;
+	data_payload = Driver::sip.data_payload;
+	dtmf_inband = Driver::sip.dtmf_inband;
 
 	update_pos = false;
 
@@ -112,6 +115,9 @@ void Session::makeIdle(void)
 	sipHangup();
 	stopRTP();
 	BayonneSession::makeIdle();
+	dtmf_inband = Driver::sip.dtmf_inband;
+	dtmf_payload = Driver::sip.dtmf_payload;
+	data_payload = Driver::sip.data_payload;
 }
 
 bool Session::enterSeize(Event *event)
