@@ -29,10 +29,13 @@ TimerPort()
 	devid = device;
 	dev = NULL;
 	buffer = NULL;
+	resetflag = false;
 }
 
 ToneThread::~ToneThread()
 {
+	bool reset = resetflag;
+	resetflag = true;
 	terminate();
 	if(buffer)
 	{
@@ -40,23 +43,30 @@ ToneThread::~ToneThread()
 		buffer = NULL;
 	}
 
-	if(dev)
+	if(dev && !reset)
 	{
-//		dev->sync();
+		session->setDevice(NULL);
 		delete dev;
 		dev = NULL;
 	}
+	else if(dev)
+	{
+		dev->flush();
+		dev = NULL;
+	}
 }
 
 void ToneThread::run(void)
 {
-	dev = getDevice(devid);
 	timeout_t timer;
 	unsigned jitter = 2;
 	timeout_t framing = 10;
 	Linear buf;
 	unsigned bufcount = framing * 8;
 
+        dev = getDevice(devid);
+        session->setDevice(dev);
+
         if(!hasDevice() && !dev)
         {
 		slog.error("%s: audio %d device unsupported", session->logname, devid);
@@ -77,7 +87,7 @@ void ToneThread::run(void)
 	
 	setTimer(0);
 	Thread::yield();
-	for(;;)
+	while(!resetflag)
 	{
 		buf = tone->getFrame();
 		if(!buf)
@@ -92,17 +102,16 @@ void ToneThread::run(void)
                 if(timer > 1 && timer != TIMEOUT_INF)
                         Thread::sleep(timer - 1);
         }
-	buffer = new Sample[bufcount];
-        memset(buffer, 0, bufcount * 2);
-        jitter = 9;
-        while(jitter--)
-        {
-                incTimer(framing);
-                dev->putSamples(buffer, bufcount);
-        }		
-	delete dev;
-	dev = NULL;
-	exit(NULL);
+	if(resetflag)
+		Thread::sync();
+
+	resetflag = true;
+        dev->flush();
+        incTimer(framing * 3);
+        timer = getTimer();
+        if(timer > 1 && timer != TIMEOUT_INF)
+                Thread::sleep(timer - 1);
+        exit(NULL);
 }
 
 PlayThread::PlayThread(Session *s, unsigned device) :
@@ -114,17 +123,28 @@ TimerPort()
 	devid = device;
 	dev = NULL;
 	buffer = NULL;
+	resetflag = false;
 }
 
 PlayThread::~PlayThread()
 {
+	bool reset = resetflag;
+
+	resetflag = true;
+
 	terminate();
-	if(dev)
+
+	if(reset && dev)
 	{
-//		dev->sync();
+		session->setDevice(NULL);
 		delete dev;
 		dev = NULL;
 	}
+	else if(dev)
+	{
+		dev->flush();
+		dev = NULL;
+	}
 	if(audio->isOpen() && session->state.audio.mode != modeReadAny)
 		audio->getPosition(audio->var_position, 12);
 	audio->cleanup();
@@ -139,10 +159,12 @@ PlayThread::~PlayThread()
 void PlayThread::run(void)
 {
 	unsigned bufcount, pages;
-	dev = getDevice(devid);
 	Info info;
 	timeout_t timer;
 	unsigned jitter = 2;
+
+	dev = getDevice(devid);
+	session->setDevice(dev);
 	
 	if(!hasDevice() && !dev)
 	{
@@ -185,7 +207,7 @@ void PlayThread::run(void)
                 buffer = new Sample[bufcount];
 
 	setTimer(0);
-	for(;;)
+	while(!resetflag)
 	{
                 if(isStereo(info.encoding))
                         pages = audio->getStereo(buffer, 1);
@@ -204,20 +226,16 @@ void PlayThread::run(void)
 		if(timer > 1 && timer != TIMEOUT_INF)
 			Thread::sleep(timer - 1);
 	}
-	memset(buffer, 0, bufcount * 2);
-	jitter = 9;
-	while(jitter--)
-	{
-		incTimer(info.framing);
-		dev->putSamples(buffer, bufcount);
-	}
-/*	timer = getTimer();
+	if(resetflag)
+		Thread::sync();
+
+	resetflag = true;
+
+	dev->flush();
+	incTimer(info.framing * 3);
+	timer = getTimer();
 	if(timer > 1 && timer != TIMEOUT_INF)
-		Thread::sleep(timer);
-*/
-	dev->sync();
-	delete dev;
-	dev = NULL;
+		Thread::sleep(timer - 1);
 	exit(NULL);
 }
 
@@ -230,6 +248,7 @@ TimerPort()
         devid = device;
         dev = NULL;
         buffer = NULL;
+	resetflag = false;
 
 	if(s->state.audio.total)
 		setTimer(s->state.audio.total);
@@ -237,12 +256,21 @@ TimerPort()
 
 RecordThread::~RecordThread()
 {
+	bool reset = resetflag;
+	resetflag = true;
+
         terminate();
-        if(dev)
+
+	if(dev && resetflag)
+	{
+		session->setDevice(NULL);
+		delete dev;
+		dev = NULL;
+	}
+        else if(dev)
         {
-//                dev->sync();
-                delete dev;
-                dev = NULL;
+		dev->flush();
+		dev = NULL; 
         }
         if(audio->isOpen())
                 audio->getPosition(audio->var_position, 12);
@@ -258,7 +286,6 @@ RecordThread::~RecordThread()
 void RecordThread::run(void)
 {
         unsigned bufcount, pages;
-        dev = getDevice(devid, RECORD);
         Info info;
 	bool silent = true;
 	bool compress = session->state.audio.compress;
@@ -268,6 +295,9 @@ void RecordThread::run(void)
 	Level peak;
 	Event event;
 
+	dev = getDevice(devid, RECORD);
+	session->setDevice(dev);
+
 	if(session->state.audio.silence || compress)
 		silence = true;
 
@@ -350,6 +380,7 @@ void RecordThread::run(void)
 skip:
 		Thread::yield();
 	}
+	resetflag = true;
 	exit(NULL);
 }	
 	
