@@ -47,7 +47,10 @@ BayonneService(-1, 0), Keydata(KEYS)
         if(env)
                 loadFile(env, "tcpmon");
 #else
-        load("~bayonne/tcpmon");
+	if(Bayonne::provision_system)
+		load("/bayonne/provision/tcpmon");
+	else if(Bayonne::provision_user)
+	        load("~bayonne/tcpmon");
 #endif
 
 }
