@@ -663,7 +663,7 @@ bool Methods::scrLibexec(void)
 	}
 
 	if(sym)
-		clear(sym);
+		Script::clear(sym);
 
 	state.wait.interval = 250;
 	cp = getKeyword("limit");
